@@ -84,7 +84,7 @@
 #define PLASMAQUICK_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PLASMAQUICK_NO_DEPRECATED
-#  define PLASMAQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56e00
+#  define PLASMAQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57200
 #endif
 #ifdef PLASMAQUICK_NO_DEPRECATED_WARNINGS
 #  define PLASMAQUICK_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef PLASMAQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PLASMAQUICK_DEPRECATED_WARNINGS_SINCE PLASMAQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PLASMAQUICK_DEPRECATED_WARNINGS_SINCE 0x56e00
+#    define PLASMAQUICK_DEPRECATED_WARNINGS_SINCE 0x57200
 #  endif
 #endif
 
